<?php

namespace App\DataTables;

use App\AuctionObject;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Services\DataTable;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Html\Editor\Editor;

class AuctionObjectDataTable extends DataTable
{
    /**
     * Build DataTable class.
     *
     * @param mixed $query Results from query() method.
     * @return \Yajra\DataTables\DataTableAbstract
     */
    public function dataTable($query)
    {
        return datatables()
            ->eloquent($query)
            ->addColumn('action', '
                <a class="action-icon" href="/objekt-bearbeiten/{{$id}}" title="Kunstobjekt bearbeiten"><i class="fa fa-pencil" aria-hidden="true"></i></a> 
            ');
    }

    /**
     * Get query source of dataTable.
     *
     * @param \App\AuctionObject $model
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function query(AuctionObject $model)
    {
        $query = null;

        $query = $model->newQuery()
            //->leftJoin('t_language as language', 'language.id', '=', 't_language_id')
            //->leftJoin('t_medium_category as m', 'm.id', '=', 't_medium_category_id')
            //->leftJoin('t_source_type as st', 'st.id', '=', 't_source_type_id')
            ->select(
                'id',
                'crawl_id',
                'status',
                'object_id',
                'source_type',
                't_source_type_id',
                't_artist_id',
                't_language_id',
                't_medium_category_id',
                'lot_no',
                'auction_no',
                'auction_name',
                'auction_loc',
                'auction_date',
                //DB::raw("DATE_FORMAT(auction_date, '%d.%m.%Y') as auction_date"),
                'artist_firstname',
                'artist_lastname',
                'artist_born_loc',
                DB::raw("DATE_FORMAT(artist_born_date, '%d.%m.%Y') as artist_born_date"),
                DB::raw("DATE_FORMAT(artist_died_date, '%d.%m.%Y') as artist_died_date"),
                'artist_died_loc',
                'object_title',
                'object_medium',
                'object_date_pre',
                'object_date',
                'object_date_post',
                'object_height',
                'object_width',
                'object_depth',
                'object_size_unit',
                'object_est_from',
                'object_est_to',
                'object_est_curr',
                't_currency_est_id',
                'object_sold',
                'object_result_curr',
                't_currency_result_id',
                'object_result',
                'object_url',
                'object_image_url',
                'object_indicators',
                DB::raw("DATE_FORMAT(crawled_at, '%d.%m.%Y %H:%i') as crawled_at"),
                DB::raw("DATE_FORMAT(created_at, '%d.%m.%Y %H:%i') as created_at"),
                'hash_value',
                'editor',
                'lastchange'
                //'language.language as language_name'
                //'language.lang_code as lang_code'
                //'m.name as medium_category',
                //'st.name as source_type_name'
            );

        // TODO: Filter

        return $query;
    }

    /**
     * Optional method if you want to use html builder.
     *
     * @return \Yajra\DataTables\Html\Builder
     */
    public function html()
    {
        return $this->builder()
            ->setTableId('data-table-auction-object')
            ->addTableClass('cell-border data-table display table table-data-width nowrap')
            ->pageLength(Auth::user()->table_page_length)
            ->lengthMenu([ 10, 25, 50, 100 ])
            ->columns($this->getColumns())
            ->minifiedAjax()
            ->parameters([
                'dom' => 'Blfrtip',
                'buttons' => ['pageLength'],
            ])
            ->orderBy(34, 'asc')
            ->language('/plugins/datatables/i18n/German.json')
            ->initComplete("
                function (settings, json) {
                    $('#filterContainer').prependTo('.dataTables_wrapper');
                    $('#filterContainer').show();
                }
            ");
    }

    /**
     * Get columns.
     *
     * @return array
     */
    protected function getColumns()
    {
        return [
            Column::computed('action')
                ->exportable(false)
                ->printable(false)
                ->width(90)
                ->addClass('text-center'),
            Column::make('language.lang_code', 'language.lang_code')->title('Sprache'),
            Column::make('auction_name', 'auction_name')->title('Auktion'),
            Column::make('source_type_name', 'source_type_name')->title('Auktionshaus (ID)'),
            Column::make('artist_firstname', 'artist_firstname')->title('Künstler VN'),
            Column::make('artist_lastname', 'artist_lastname')->title('Künstler NN'),
            Column::make('artist_born_loc', 'artist_born_loc')->title('Künstler Geb.Ort'),
            Column::make('artist_born_date', 'artist_born_date')->title('Künstler Geb.Dat.'),
            Column::make('artist_died_loc', 'artist_died_loc')->title('Künstler Gest.Ort'),
            Column::make('artist_died_date', 'artist_died_date')->title('Künstler Gest.Dat.'),
            Column::make('medium_category', 'medium_category')->title('Grobtechnik'),
            Column::make('object_medium', 'object_medium')->title('Technik'),
            Column::make('object_url', 'object_url')->title('Pfad'),
            Column::make('auction_no', 'auction_no')->title('Auktionsnr.'),
            Column::make('lot_no', 'lot_no')->title('Lot Nr.'),
            Column::make('object_title', 'object_title')->title('Titel'),
            Column::make('object_date_pre', 'object_date_pre')->title('Entst.Txt 1'),
            Column::make('object_date', 'object_date')->title('Entstehung'),
            Column::make('object_date_post', 'object_date_post')->title('Entst.Txt 2'),
            Column::make('object_est_from', 'object_est_from')->title('SP von'),
            Column::make('object_est_to', 'object_est_to')->title('SP bis'),
            Column::make('object_est_curr', 'object_est_curr')->title('SP Währ.'),
            Column::make('object_result', 'object_result')->title('Erlös'),
            Column::make('object_result_curr', 'object_result_curr')->title('Erlös Währ.'),
            Column::make('object_indicators', 'object_indicators')->title('Katalog'),
            Column::make('object_height', 'object_height')->title('Höhe'),
            Column::make('object_width', 'object_width')->title('Breite'),
            Column::make('object_depth', 'object_depth')->title('Tiefe'),
            Column::make('object_size_unit', 'object_size_unit')->title('Einheit'),
            Column::make('object_image_url', 'object_image_url')->title('Bildpfad'),
            Column::make('auction_loc', 'auction_loc')->title('Auktionsort'),
            Column::make('auction_date', 'auction_date')->title('Auktionsdat.'),
            Column::make('source_type', 'source_type')->title('Auktionshaus'),
            Column::make('object_id', 'object_id')->title('Objektnr.'),
            Column::make('id', 'id')->title('ID'),
            Column::make('created_at', 'created_at')->title('Anlagedat.'),
            Column::make('crawled_at', 'crawled_at')->title('Auslesedat.'),
        ];
    }

    /**
     * Get filename for export.
     *
     * @return string
     */
    protected function filename()
    {
        return 'AuctionObject_' . date('YmdHis');
    }
}
