<?php

namespace App\DataTables;

use App\MediumCategory;
use Illuminate\Support\Facades\Auth;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Services\DataTable;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Html\Editor\Editor;

class MediumCategoryDataTable extends DataTable
{
    /**
     * Build DataTable class.
     *
     * @param mixed $query Results from query() method.
     * @return \Yajra\DataTables\DataTableAbstract
     */
    public function dataTable($query)
    {
        /*return datatables()
            ->eloquent($query)
            ->addColumn('action', '
                <a class="action-icon" href="/grobtechnik-bearbeiten/{{$id}}" title="Grobtechnik bearbeiten"><i class="fa fa-pencil" aria-hidden="true"></i></a>
                <a class="action-icon" href="javascript:confirmDeleteMediumCategory({{$id}})" title="Grobtechnik löschen"><i class="fa fa-trash" aria-hidden="true"></i></a>
            ');*/
        return datatables()
            ->eloquent($query);
    }

    /**
     * Get query source of dataTable.
     *
     * @param \App\MediumCategory $model
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function query(MediumCategory $model)
    {
        return $model->newQuery()->select('id', 'name');
    }

    /**
     * Optional method if you want to use html builder.
     *
     * @return \Yajra\DataTables\Html\Builder
     */
    public function html()
    {
        $page = ($this->pageParam == '') ? null : $this->pageParam;
        $len = ($this->lenParam == '') ? 10 : $this->lenParam;
        $sortc = ($this->sortcParam == '') ? 2 : $this->sortcParam;
        $sortd = ($this->sortdParam == '') ? 'asc' : $this->sortdParam;

        if ($this->pageParam != null) {

            $displayStart = ($page - 1) * $len;
        } else {

            $displayStart = 0;
        }

        return $this->builder()
            ->setTableId('data-table-medium-category')
            ->addTableClass('cell-border data-table display table table-data-width nowrap')
            ->pageLength($this->pageLength)
            ->lengthChange(false)
            ->displayStart($displayStart)
            ->lengthMenu([ 10, 25, 50, 100 ])
            ->columns($this->getColumns())
            ->minifiedAjax()
            ->parameters([
                'dom' => 'Blfrtip',
                'buttons' => ['pageLength'],
            ])
            ->orderBy($sortc, $sortd)
            ->language('/plugins/datatables/i18n/German.json')
            ->initComplete("
                function (settings, json) {
                    $('#filterContainer').insertAfter('#data-table-medium-category_filter');
                    $('#buttonLine').insertBefore('#data-table-medium-category_filter');
                    $('#filterContainer').show();
                    $('#buttonLine').show();
                }
            ");
    }

    /**
     * Get columns.
     *
     * @return array
     */
    protected function getColumns()
    {
        return [
            /*Column::computed('action')
                ->exportable(false)
                ->printable(false)
                ->width(60)
                ->addClass('text-center'),*/
            Column::computed('action')
                ->title('')
                ->render('function(){
                    var actions = \'\';
                    var page = $("#data-table-medium-category").DataTable().page.info().page+1;
                    var length = $("#data-table-medium-category").DataTable().page.info().length;
                    var sortc = $("#data-table-medium-category").DataTable().order()[0][0];
                    var sortd = $("#data-table-medium-category").DataTable().order()[0][1];

                    actions += \' <a class="action-icon" href="/grobtechnik-bearbeiten/\'+full.id+\'/?page=\'+page+\'&len=\'+length+\'&sortc=\'+sortc+\'&sortd=\'+sortd+\'" title="Grobtechnik bearbeiten"><i class="fa fa-pencil" aria-hidden="true"></i></a> \';
                    actions += \' <a class="action-icon" href="javascript:confirmDeleteMediumCategory(\'+full.id+\', \\\'\'+page+\'\\\', \\\'\'+length+\'\\\', \\\'\'+sortc+\'\\\', \\\'\'+sortd+\'\\\')" title="Grobtechnik löschen"><i class="fa fa-trash" aria-hidden="true"></i></a> \';

                    return actions;
                }')
                ->exportable(false)
                ->printable(false)
                ->width(60)
                ->addClass('text-center'),
            Column::make('name', 'name')->title('Name *'),
            Column::make('id', 'id')->title('ID')->width(60),
        ];
    }

    /**
     * Get filename for export.
     *
     * @return string
     */
    protected function filename()
    {
        return 'MediumCategory_' . date('YmdHis');
    }
}
