<?php

namespace App\DataTables;

use App\MediumCategory;
use App\User;
use Illuminate\Validation\Rule;
use Yajra\DataTables\DataTablesEditor;
use Illuminate\Database\Eloquent\Model;

class MediumCategoryDataTableEditor extends DataTablesEditor
{
    protected $model = MediumCategory::class;

    /**
     * Get create action validation rules.
     *
     * @return array
     */
    public function createRules()
    {
        return [
            'name'  => 'required',
        ];
    }

    /**
     * Get edit action validation rules.
     *
     * @param Model $model
     * @return array
     */
    public function editRules(Model $model)
    {
        return [
            'name'  => 'sometimes|required',
        ];
    }

    /**
     * Get remove action validation rules.
     *
     * @param Model $model
     * @return array
     */
    public function removeRules(Model $model)
    {
        return [];
    }

    /**
     * Override messages with custom messages
     *
     * @return array
     */
    public function editMessages()
    {
        return [
            'name'             => 'Bitte geben Sie den Namen ein',
        ];
    }

    /**
     * Pre-create action event hook.
     *
     * @param Model $model
     * @return array
     */
    public function creating(Model $model, array $data)
    {
        $data['name'] = $data['name'];

        return $data;
    }

    /**
     * Pre-update action event hook.
     *
     * @param Model $model
     * @return array
     */
    public function updating(Model $model, array $data)
    {
        if (empty($data['name'])) {
            unset($data['name']);
        } else {
            $data['name'] = $data['name'];
        }

        return $data;
    }
}
