<?php

namespace App\DataTables;

use App\SourceType;
use App\User;
use Illuminate\Validation\Rule;
use Yajra\DataTables\DataTablesEditor;
use Illuminate\Database\Eloquent\Model;

class SourceTypeDataTableEditor extends DataTablesEditor
{
    protected $model = SourceType::class;

    /**
     * Get create action validation rules.
     *
     * @return array
     */
    public function createRules()
    {
        return [
            //'email' => 'required|email|unique:' . $this->resolveModel()->getTable(),
            'name'  => 'required',
            'location'  => 'required',
            'url'  => 'required',
        ];
    }

    /**
     * Get edit action validation rules.
     *
     * @param Model $model
     * @return array
     */
    public function editRules(Model $model)
    {
        return [
            //'email' => 'sometimes|required|email|' . Rule::unique($model->getTable())->ignore($model->getKey()),
            'name'  => 'sometimes|required',
            'location'  => 'sometimes|required',
            //'url'  => 'sometimes|url',
        ];
    }

    /**
     * Override messages with custom messages
     *
     * @return array
     */
    public function editMessages()
    {
        return [
            'name'             => 'Bitte geben Sie den Namen ein',
            'location'         => 'Bitte geben Sie den Standort ein',
            'url'              => 'Bitte geben Sie eine gültige URL ein',
        ];
    }

    /**
     * Get remove action validation rules.
     *
     * @param Model $model
     * @return array
     */
    public function removeRules(Model $model)
    {
        return [];
    }

    /**
     * Pre-create action event hook.
     *
     * @param Model $model
     * @return array
     */
    public function creating(Model $model, array $data)
    {
        $data['name'] = $data['name'];

        return $data;
    }

    /**
     * Pre-update action event hook.
     *
     * @param Model $model
     * @return array
     */
    public function updating(Model $model, array $data)
    {
        if (empty($data['name'])) {
            unset($data['name']);
        } else {
            $data['name'] = $data['name'];
        }

        return $data;
    }
}
