<?php

namespace App\Http\Controllers\Ajax;

use App\AuctionObject;
use App\AuctionObjectStage;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;

class AuctionObjectsImportOverviewController extends Controller
{
    public function getData(Request $request) {

        $filterStatus = $request->status;
        $filterLanguage = $request->lang;
        $filterAuctionName = urldecode($request->an);

        $data = DB::connection('mysql_stage')
            ->table('t_import_stage as ao')
            //->leftJoin('t_language as l', 'l.id', '=', 'ao.t_language_id')
            ->select(
                'ao.id',
                'ao.status',
                'ao.filename',
                'ao.user',
                DB::raw("DATE_FORMAT(ao.uploadTime, '%d.%m.%Y %H:%i') as uploadTime"),
                'ao.auctionHouse',
                'ao.auctionName',
                'ao.auctionDate',
                'ao.lotnum',
                'ao.artist',
                'ao.title',
                'ao.indicators',
                'ao.workDate',
                'ao.medium',
                'ao.dimensions',
                'ao.estimates',
                'ao.publisher',
                'ao.printer',
                'ao.catRaisAuthor',
                'ao.catRaisNumber',
                'ao.edition',
                'ao.printingDate',
                'ao.imageUrl',
                'ao.lotUrl'
            );

        if(!is_null($filterStatus)) {
            $data->where('ao.status', $filterStatus);
        }

        /*if(!is_null($filterLanguage)) {
            $data->where('ao.t_language_id', $filterLanguage);
        }

        if(!empty($filterAuctionName)) {
            $data->where('ao.auction_name', $filterAuctionName);
        }*/

        return Datatables::of($data)->make(true);
    }

    /**
     * @param Request $request
     * @return string
     */
    public function bulkEditStatus(Request $request) {

        $start = microtime(true);

        $bulkAction = $request->bulk_action;

        $arrSelectedRows = $request->dt_checkbox;

        $userId = Auth::user()->id;

        $data = array();

        foreach($arrSelectedRows as $selectedRowId) {

            array_push($data, ['id'=>$selectedRowId, 'status'=>$bulkAction, 'user'=>$userId]);
        }

        $this->custom_batch_update('t_import_stage', 'id', $data);

        $end = microtime(true);

        $diff = ($end - $start);
        return "Laufzeit (Sek.): " . number_format($diff,4,',','.');

        //return '200';
    }

    /**
     * @param string $table_name Table name
     * @param string $key Which column is the selective column
     * @param array $update_arr Data array
     * @return int Affected Rows
     */
    private function custom_batch_update(string $table_name = '', string $key = '', Array $update_arr = array()) {

        if(!$table_name || !$key || !$update_arr){
            return false;
        }

        $update_keys = array_keys($update_arr[0]);
        $update_keys_count = count($update_keys);

        for ($i = 0; $i < $update_keys_count; $i++) {
            $key_name = $update_keys[$i];
            if($key === $key_name){
                continue;
            }
            $when_{$key_name} = $key_name . ' = CASE';
        }

        $length = count($update_arr);
        $index = 0;
        $query_str = 'UPDATE ' . $table_name . ' SET ';
        $when_str = '';
        $where_str = ' WHERE ' . $key . ' IN(';

        while ($index < $length) {
            $when_str = " WHEN $key = '{$update_arr[$index][$key]}' THEN";
            $where_str .= "'{$update_arr[$index][$key]}',";
            for ($i = 0; $i < $update_keys_count; $i++) {
                $key_name = $update_keys[$i];
                if($key === $key_name){
                    continue;
                }
                $when_{$key_name} .= $when_str . " '{$update_arr[$index][$key_name]}'";
            }
            $index++;
        }

        for ($i = 0; $i < $update_keys_count; $i++) {
            $key_name = $update_keys[$i];
            if($key === $key_name){
                continue;
            }
            $when_{$key_name} .= ' ELSE ' . $key_name . ' END, ';
            $query_str .= $when_{$key_name};
        }
        $query_str = rtrim($query_str, ', ');
        $where_str = rtrim($where_str, ',') . ')';
        $query_str .= $where_str;
        $affected = DB::connection('mysql_stage')->update($query_str);

        return $affected;
    }
}
