<?php

namespace App\Http\Controllers\Ajax;

use App\AuctionObject;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;
use Yajra\DataTables\Facades\DataTables;

class AuctionObjectsOverviewController extends Controller
{
    public function getData(Request $request) {

        $filterStatus = $request->status;
        $filterLanguage = $request->lang;
        $filterSourceType = $request->st;
        $filterSearchColumn = $request->sc;
        $filterSearch = stripslashes($request->s);

        $searchColumns = Schema::getColumnListing('t_auction_object');

        // if all filters are not selected provoke an empty result
        if( is_null($filterStatus) && is_null($filterLanguage) && is_null($filterSourceType) && strlen($filterSearch) == 0 ) {

            return json_encode(array('data'=>''));

        } else {

            $data = DB::table('t_auction_object as ao')
                ->leftJoin('t_language as l', 'l.id', '=', 'ao.t_language_id')
                ->leftJoin('t_medium_category as m', 'm.id', '=', 'ao.t_medium_category_id')
                ->leftJoin('t_source_type as st', 'st.id', '=', 'ao.t_source_type_id')
                ->leftJoin('t_artist as a', 'a.id', '=', 'ao.t_artist_id')
                ->select(
                    'ao.id',
                    'ao.crawl_id',
                    'ao.status',
                    'ao.object_id',
                    'ao.source_type',
                    'ao.t_source_type_id',
                    'ao.t_artist_id',
                    'ao.t_language_id',
                    'ao.t_medium_category_id',
                    'ao.lot_no',
                    'ao.auction_no',
                    'ao.auction_name',
                    'ao.auction_loc',
                    'ao.auction_date',
                    //DB::raw("DATE_FORMAT(ao.auction_date, '%d.%m.%Y') as auction_date"),
                    'ao.artist_firstname',
                    'ao.artist_lastname',
                    'ao.artist_born_loc',
                    DB::raw("DATE_FORMAT(ao.artist_born_date, '%Y') as artist_born_date"),
                    DB::raw("DATE_FORMAT(ao.artist_died_date, '%Y') as artist_died_date"),
                    'ao.artist_died_loc',
                    'ao.object_title',
                    'ao.object_medium',
                    'ao.object_date_pre',
                    'ao.object_date',
                    'ao.object_date_post',
                    'ao.object_height',
                    'ao.object_width',
                    'ao.object_depth',
                    'ao.object_size_unit',
                    'ao.object_est_from',
                    'ao.object_est_to',
                    'ao.object_est_curr',
                    'ao.t_currency_est_id',
                    'ao.object_sold',
                    'ao.object_result_curr',
                    'ao.t_currency_result_id',
                    'ao.object_result',
                    'ao.object_url',
                    'ao.object_image_url',
                    'ao.object_indicators',
                    DB::raw("DATE_FORMAT(ao.crawled_at, '%d.%m.%Y %H:%i') as crawled_at"),
                    DB::raw("DATE_FORMAT(ao.created_at, '%d.%m.%Y %H:%i') as created_at"),
                    'ao.hash_value',
                    'ao.editor',
                    'ao.lastchange',
                    'l.language as language_name',
                    'l.lang_code as lang_code',
                    'm.name as medium_category',
                    'st.name as source_type_name',
                    DB::raw("
                        CASE
                            WHEN a.firstname_de IS NOT NULL or a.lastname_de IS NOT NULL THEN CONCAT( SUBSTRING( CONCAT( IFNULL(a.firstname_de,''), ' ', IFNULL(a.lastname_de,'') ),1,20 ),'')
                            WHEN a.firstname_en IS NOT NULL or a.lastname_en IS NOT NULL THEN CONCAT( SUBSTRING( CONCAT( IFNULL(a.firstname_en,''), ' ', IFNULL(a.lastname_en,'') ),1,20 ),'')
                            WHEN a.firstname_fr IS NOT NULL or a.lastname_fr IS NOT NULL THEN CONCAT( SUBSTRING( CONCAT( IFNULL(a.firstname_fr,''), ' ', IFNULL(a.lastname_fr,'') ),1,20 ),'')
                        END AS artist_fullname
                    "),
                    'ao.status_message'
                );

            if(!is_null($filterStatus)) {
                $data->where('ao.status', $filterStatus);
            }

            if(!is_null($filterLanguage)) {
                $data->where('ao.t_language_id', $filterLanguage);
            }

            if(!is_null($filterSourceType)) {
                $data->where('ao.t_source_type_id', $filterSourceType);
            }

            if(!is_null($filterSearch)) {
                if ($filterSearchColumn == 'all') {

                    $data->where(function($q) use ($filterSearch)
                    {
                        $q->from('t_auction_objects')
                            ->where('ao.auction_name', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.artist_firstname', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.artist_lastname', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.artist_born_loc', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.artist_born_date', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.artist_died_date', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.artist_died_loc', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_medium', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_url', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.auction_no', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.lot_no', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_title', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_date_pre', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_date', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_date_post', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_est_from', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_est_to', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_est_curr', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_result', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_result_curr', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_indicators', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_height', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_width', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_depth', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_size_unit', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_image_url', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.auction_loc', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.auction_date', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.source_type', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.object_id', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.id', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.created_at', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('ao.crawled_at', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('a.firstname_de', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('a.firstname_en', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('a.firstname_fr', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('a.lastname_de', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('a.lastname_en', 'LIKE', '%'.$filterSearch.'%')
                            ->orWhere('a.lastname_fr', 'LIKE', '%'.$filterSearch.'%');
                    });

                } else {
                    if ($filterSearchColumn == 'artist_fullname') {
                        $data->where(DB::raw("CONCAT(a.firstname_de,' ', a.lastname_de)"), 'LIKE', '%'.$filterSearch.'%');
                        $data->orWhere(DB::raw("CONCAT(a.firstname_en,' ', a.lastname_en)"), 'LIKE', '%'.$filterSearch.'%');
                        $data->orWhere(DB::raw("CONCAT(a.firstname_fr,' ', a.lastname_fr)"), 'LIKE', '%'.$filterSearch.'%');
                    } elseif ($filterSearchColumn == 'medium_category') {
                        $data->where('m.name', 'LIKE', '%'.$filterSearch.'%');
                    }  else {
                        $data->where('ao.'.$filterSearchColumn, 'LIKE', '%'.$filterSearch.'%');
                    }
                }
            }

            return Datatables::of($data)->make(true);
        }

    }

    /**
     * @param Request $request
     * @return string
     */
    public function bulkEditStatus(Request $request) {

        $bulkAction = $request->bulk_action;

        $arrSelectedRows = $request->dt_checkbox;

        foreach($arrSelectedRows as $selectedRowId) {

            $auctionObject = new AuctionObject();
            $auctionObject = $auctionObject->find($selectedRowId);

            $auctionObject->status = $bulkAction;
            $auctionObject->save();
        }

        return '200';

    }
}
