<?php

namespace App\Http\Controllers\Artists;

use App\Artist;
use App\AuctionObject;
use App\User;
use App\UserRole;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Validator;

class ArtistController extends Controller
{
    /**
     * ArtistController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('artists.create-artist', []);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // validate form
        $validator = Validator::make($request->all(), [
            'status'             => 'required',
            'gender_id'          => '',
            'firstname_de'       => '',
            'firstname_en'       => '',
            'firstname_fr'       => '',
            'lastname_de'        => '',
            'lastname_en'        => '',
            'lastname_fr'        => '',
            'born_date'          => '',
            'born_location_de'   => '',
            'born_location_en'   => '',
            'born_location_fr'   => '',
            'died_date'          => '',
            'died_location_de'   => '',
            'died_location_en'   => '',
            'died_location_fr'   => '',
            'editor'             => '',
        ], [
            'status.required' => 'Bitte wählen Sie den Status aus',
            'gender_id.required' => 'Bitte wählen Sie das Geschlecht aus',
            'firstname_de.required' => 'Bitte geben Sie den Vornamen DE ein',
            'firstname_en.required' => 'Bitte geben Sie den Vornamen EN ein',
            'firstname_fr.required' => 'Bitte geben Sie den Vornamen FR ein',
            'lastname_de.required' => 'Bitte geben Sie den Nachnamen DE ein',
            'lastname_en.required' => 'Bitte geben Sie den Nachnamen EN ein',
            'lastname_fr.required' => 'Bitte geben Sie den Nachnamen FR ein',
            'born_date.required' => 'Bitte geben Sie das Geburtsdateum ein',
            'born_location_de.required' => 'Bitte geben Sie den Geburtsort DE ein',
            'born_location_en.required' => 'Bitte geben Sie den Geburtsort EN ein',
            'born_location_fr.required' => 'Bitte geben Sie den Geburtsort FR ein',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $artist = new Artist();
            $artist->status = $request->status;
            $artist->gender_id = $request->gender_id;
            $artist->firstname_de = $request->firstname_de;
            $artist->firstname_en = $request->firstname_en;
            $artist->firstname_fr = $request->firstname_fr;
            $artist->lastname_de = $request->lastname_de;
            $artist->lastname_en = $request->lastname_en;
            $artist->lastname_fr = $request->lastname_fr;
            $artist->born_date = $request->born_date;
            $artist->born_location_de = $request->born_location_de;
            $artist->born_location_en = $request->born_location_en;
            $artist->born_location_fr = $request->born_location_fr;
            $artist->died_date = $request->died_date;
            $artist->died_location_de = $request->died_location_de;
            $artist->died_location_en = $request->died_location_en;
            $artist->died_location_fr = $request->died_location_fr;
            $artist->editor = $request->editor;
            $artist->created_at = Carbon::now();
            $artist->save();

            $artistId = $artist->id;

            // call rest service
            //$this->restCallPrepareArtistForMatching($request, $artistId);
            $this->restCallMatchAndPrepareOneTartistForAllTauctionObjects($request, $artistId);

            return redirect()->route('artists', ['c'=>1]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id,  Request $request)
    {
        $artistId = (int) $id;

        $status = $request->status;
        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $artist = Artist::where('id', $artistId)
            ->first();

        return view('artists.edit-artist', ['artist'=>$artist, 'status'=>$status, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $artistId = (int) $id;

        $status = $request->selected_status;
        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $validator = Validator::make($request->all(), [
            'status'             => '',
            'gender'             => '',
            'firstname_de'       => '',
            'firstname_en'       => '',
            'firstname_fr'       => '',
            'lastname_de'        => '',
            'lastname_en'        => '',
            'lastname_fr'        => '',
            'born_date'          => '',
            'born_location_de'   => '',
            'born_location_en'   => '',
            'born_location_fr'   => '',
            'died_date'          => '',
            'died_location_de'   => '',
            'died_location_en'   => '',
            'died_location_fr'   => '',
            'editor'             => '',
        ], [
            'status.required' => 'Bitte wählen Sie den Status aus',
            'firstname_de.required' => 'Bitte geben Sie den Vornamen DE ein',
            'firstname_en.required' => 'Bitte geben Sie den Vornamen EN ein',
            'firstname_fr.required' => 'Bitte geben Sie den Vornamen FR ein',
            'lastname_de.required' => 'Bitte geben Sie den Nachnamen DE ein',
            'lastname_en.required' => 'Bitte geben Sie den Nachnamen EN ein',
            'lastname_fr.required' => 'Bitte geben Sie den Nachnamen FR ein',
            'born_date.required' => 'Bitte geben Sie das Geburtsdateum ein',
            'born_location_de.required' => 'Bitte geben Sie den Geburtsort DE ein',
            'born_location_en.required' => 'Bitte geben Sie den Geburtsort EN ein',
            'born_location_fr.required' => 'Bitte geben Sie den Geburtsort FR ein',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $artist = new Artist();
            $artist = $artist->find($artistId);

            $artist->status = $request->status;
            $artist->firstname_de = $request->firstname_de;
            $artist->firstname_en = $request->firstname_en;
            $artist->firstname_fr = $request->firstname_fr;
            $artist->lastname_de = $request->lastname_de;
            $artist->lastname_en = $request->lastname_en;
            $artist->lastname_fr = $request->lastname_fr;
            $artist->born_date = $request->born_date;
            $artist->born_location_de = $request->born_location_de;
            $artist->born_location_en = $request->born_location_en;
            $artist->born_location_fr = $request->born_location_fr;
            $artist->died_date = $request->died_date;
            $artist->died_location_de = $request->died_location_de;
            $artist->died_location_en = $request->died_location_en;
            $artist->died_location_fr = $request->died_location_fr;
            $artist->editor = $request->editor;
            $artist->save();

            // call rematching service
            //$this->restCallPrepareArtistForMatching($request, $artistId);
            //$this->restCallMatchAllArtists($request);
            $this->restCallMatchAndPrepareOneTartistForAllTauctionObjects($request, $artistId);

            if ($request->status == 1) {
                $this->restCallCheckArtistFirstnamesInTGenderLookupAndSaveArtistFirstname($request, $artistId);
            }

            return redirect()->route('artists', ['status'=>$status, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd, 'u'=>1]);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $artistId = (int) $request->artist_id;
        $artistPage = (int) $request->artist_page;
        $artistLength = (int) $request->artist_length;
        $artistSortColumn = (int) $request->artist_sort_column;
        $artistSortDirection = (int) $request->artist_sort_direction;

        $numberOfAssignedObjects = AuctionObject::where('t_artist_id', $artistId)
            ->where('status', 2)
            ->count();

        // if assigned objects with status exported exists dont delete artist
        // else delete user and assignments
        if($numberOfAssignedObjects > 0) {

            return redirect()->route('artists', ['del'=>0, 'page'=>$artistPage, 'len'=>$artistLength, 'sortc'=>$artistSortColumn, 'sortd'=>$artistSortDirection]);
        } else {

            $artist = Artist::find($artistId);

            if($artist){
                // at first delete object assignments
                $auctionObject = AuctionObject::where('t_artist_id', $artistId)
                    ->whereNotIn('status', [2])
                    ->update(
                        [
                            'status'=>3,
                            't_artist_id'=>null
                        ]
                    );

                // finally delete artist
                $destroy = Artist::destroy($artistId);

                return redirect()->route('artists', ['del'=>1, 'page'=>$artistPage, 'len'=>$artistLength, 'sortc'=>$artistSortColumn, 'sortd'=>$artistSortDirection]);
            } else {
                return redirect()->route('artists', ['del'=>0, 'page'=>$artistPage, 'len'=>$artistLength, 'sortc'=>$artistSortColumn, 'sortd'=>$artistSortDirection]);
            }
        }


    }

    /**
     *
     */
    private function restCallMatchAndPrepareOneTartistForAllTauctionObjects(Request $request, $artistId) {

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_MATCHANDPREPAREONETARTISTFORALLTAUCTIONOBJECTS').'?tArtistId='.$artistId,
            CURLOPT_USERPWD => env('SERVICE_USERPASSWORD'),
            CURLOPT_ENCODING => "",
            //CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 10000,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "",//$jsonData,
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);
        $info = curl_getinfo($curl);
        $httpStatusCode = $info['http_code'];

        curl_close($curl);

        //$response = json_decode($response);

        if ($err) {
            echo "cURL Error #:" . $err;
        }

    }

    /**
     *
     */
    private function restCallMatchAllArtists(Request $request) {

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_MATCHALLARTISTS',null),
            CURLOPT_USERPWD => env('SERVICE_USERPASSWORD'),
            CURLOPT_ENCODING => "",
            //CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 10000,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "",//$jsonData,
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);
        $info = curl_getinfo($curl);
        $httpStatusCode = $info['http_code'];

        curl_close($curl);

        //$response = json_decode($response);

        if ($err) {
            echo "cURL Error #:" . $err;
        }

    }

    /**
     *
     */
    private function restCallPrepareArtistForMatching(Request $request, $artistId) {

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_PREPAREARTISTFORMATCHING').'?tArtistId='.$artistId,
            CURLOPT_USERPWD => env('SERVICE_USERPASSWORD'),
            CURLOPT_ENCODING => "",
            //CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 10000,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "",//$jsonData,
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);
        $info = curl_getinfo($curl);
        $httpStatusCode = $info['http_code'];

        curl_close($curl);

        $response = json_decode($response);

        if ($err) {
            echo "cURL Error #:" . $err;
        }

    }

    /**
     *
     */
    private function restCallCheckArtistFirstnamesInTGenderLookupAndSaveArtistFirstname(Request $request, $artistId) {

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_CHECKARTISTFIRSTNAMESINTGENDERLOOKUPANDSAVEARTISTFIRSTNAME').'?tArtistId='.$artistId,
            CURLOPT_USERPWD => env('SERVICE_USERPASSWORD'),
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);

        $err = curl_error($curl);
        $info = curl_getinfo($curl);
        $httpStatusCode = $info['http_code'];

        curl_close($curl);

        if ($err) {
            echo "cURL Error #:" . $err;
        }
    }
}
