<?php

namespace App\Http\Controllers\AuctionObjects;

use App\Artist;
use App\AuctionObject;
use App\Helpers\AuctionObjectHelper;
use App\Medium;
use App\MediumCategory;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Validator;

class AuctionObjectController extends Controller
{

    /**
     * AuctionObjectController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Request $request)
    {
        $status = $request->status;
        $lang = $request->lang;
        $sourceType = $request->st;
        $searchColumns = $request->sc;
        $search = $request->s;
        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $auctionObjectId = $id;

        $auctionObject = DB::table('t_auction_object as ao')
            ->leftJoin('t_source_type as st', 'st.id', '=', 'ao.t_source_type_id')
            ->leftJoin('t_artist as a', 'a.id', '=', 'ao.t_artist_id')
            ->select(
                'ao.*',
                DB::raw("CONCAT(a.firstname_de, ' ', a.lastname_de) artist_fullname_de"),
                DB::raw("
                    CASE
                        WHEN a.firstname_de IS NOT NULL THEN CONCAT(a.firstname_de, ' ', a.lastname_de)
                        WHEN a.lastname_de IS NOT NULL THEN CONCAT(a.firstname_de, ' ', a.lastname_de)
                        WHEN a.firstname_en IS NOT NULL THEN CONCAT(a.firstname_en, ' ', a.lastname_en)
                        WHEN a.lastname_en IS NOT NULL THEN CONCAT(a.firstname_en, ' ', a.lastname_en)
                        WHEN a.firstname_fr IS NOT NULL THEN CONCAT(a.firstname_fr, ' ', a.lastname_fr)
                        WHEN a.lastname_fr IS NOT NULL THEN CONCAT(a.firstname_fr, ' ', a.lastname_fr)
                    END AS artist_fullname
                "),
                'st.name as source_type_name'
            )
            ->where('ao.id', $auctionObjectId)
            ->first();

        /*$artists = Artist::limit(5000)
            ->get();*/

        $mediumCategories = MediumCategory::all();

        return view('auction-objects.edit-auction-object', ['auctionObject'=>$auctionObject, 'mediumCategories'=>$mediumCategories, 'status'=>$status, 'lang'=>$lang, 'sourceType'=>$sourceType, 'searchColumns'=>$searchColumns, 'search'=>$search, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $auctionId = $id;

        $status = $request->status;
        $lang = $request->lang;
        $sourceType = $request->st;
        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $validator = Validator::make($request->all(), [
            //'t_source_type_id'      => 'required',
            't_artist_id'           => 'required',
            't_medium_category_id'  => 'required',
        ], [
            't_source_type_id'              => 'Bitte weisen Sie ein Kunsthaus zu',
            't_artist_id.required'          => 'Bitte weisen Sie einen Künstler zu',
            't_medium_category_id.required' => 'Bitte weisen Sie eine Grobtechnik zu',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $auctionObject = new AuctionObject();
            $auctionObject = $auctionObject->find($auctionId);

            //$auctionObject->t_source_type_id = $request->t_source_type_id;
            $auctionObject->t_artist_id = $request->t_artist_id;
            $auctionObject->t_medium_category_id = $request->t_medium_category_id;
            $auctionObject->save();

            AuctionObjectHelper::adjustStatus($auctionId);

            return redirect()->route('auction-objects', ['status'=>$status, 'lang'=>$lang, 'st'=>$sourceType, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd, 'u'=>1]);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
