<?php

namespace App\Http\Controllers\AuctionObjects;

use App\Artist;
use App\AuctionObject;
use App\Language;
use App\MediumCategory;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class AuctionObjectsErrorOverviewController extends Controller
{

    /**
     * AuctionObjectsOverviewController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->filtered == 1) {

            $this->handleRequest($request);
        } else {

            if (is_null(session('auctionObjectsErrorLen'))) {
                // set table length
                session(['auctionObjectsErrorLen' => Auth::user()->table_page_length]);
            }
        }

        $selectedFilterStatus = session('auctionObjectsErrorStatus');
        $selectedFilterLanguage = session('auctionObjectsErrorLanguage');
        $page = session('auctionObjectsErrorPage');
        $pageLength = session('auctionObjectsErrorLen');
        $sortc = session('auctionObjectsErrorSortColumn');
        $sortd = session('auctionObjectsErrorSortDirection');

        $languages = Language::orderBy('lang_code', 'asc')
            ->get();

        $mediumCategories = MediumCategory::all();

        return view('auction-objects.error-overview', ['selectedFilterStatus'=>$selectedFilterStatus, 'selectedFilterLanguage'=>$selectedFilterLanguage, 'pageLength'=>$pageLength, 'sortc'=>$sortc, 'sortd'=>$sortd, 'mediumCategories'=>$mediumCategories, 'languages'=>$languages]);
    }

    /**
     * @param $request
     */
    public function handleRequest($request) {

        // set status in session
        if (!is_null($request->status)) {
            session(['auctionObjectsErrorStatus' => $request->status]);
        } else {
            session(['auctionObjectsErrorStatus' => null]);
        }

        // set language in session
        if (!is_null($request->lang)) {
            session(['auctionObjectsErrorLanguage' => $request->lang]);
        } else {
            session(['auctionObjectsErrorLanguage' => null]);
        }

        // set page in session
        if (!is_null($request->page)) {
            session(['auctionObjectsErrorPage' => $request->page]);
        } else {
            session(['auctionObjectsErrorPage' => null]);
        }

        // set page length in session
        if ($request->len > 0) {
            session(['auctionObjectsErrorLen' => $request->len]);
        } else {
            session(['auctionObjectsErrorLen' => Auth::user()->table_page_length]);
        }

        // set sort column in session
        if (!is_null($request->sortc)) {
            session(['auctionObjectsErrorSortColumn' => $request->sortc]);
        } else {
            session(['auctionObjectsErrorSortColumn' => null]);
        }

        // set sort direction in session
        if (!is_null($request->sortd)) {
            session(['auctionObjectsErrorSortDirection' => $request->sortd]);
        } else {
            session(['auctionObjectsErrorSortDirection' => null]);
        }
    }

}
