<?php

namespace App\Http\Controllers\AuctionObjects;

use App\Artist;
use App\AuctionObject;
use App\Language;
use App\MediumCategory;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class AuctionObjectsHistoryOverviewController extends Controller
{

    /**
     * AuctionObjectsOverviewController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->filtered == 1) {

            $this->handleRequest($request);
        } else {

            if (is_null(session('auctionObjectsHistoryLen'))) {
                // set table length
                session(['auctionObjectsHistoryLen' => Auth::user()->table_page_length]);
            }
        }

        $selectedFilterStatus = session('auctionObjectsHistoryStatus');
        $selectedFilterLanguage = session('auctionObjectsHistoryLanguage');
        $page = session('auctionObjectsHistoryPage');
        $pageLength = session('auctionObjectsHistoryLen');
        $sortc = session('auctionObjectsHistorySortColumn');
        $sortd = session('auctionObjectsHistorySortDirection');

        /*$languages = Language::orderBy('lang_code', 'asc')
            ->get();*/

        // Language Filter - get entired languages
        $languages = DB::table('t_auction_object_history as ao')
            ->leftJoin('t_language as l', 'l.id', '=', 'ao.t_language_id')
            ->select(
                'ao.t_language_id as id',
                'l.language as language_name',
                'l.lang_code as lang_code'
            )
            ->distinct();

        $languages = $languages->get();

        // Status Filter - get entired statuses
        $statuses = DB::table('t_auction_object_history as ao')
            ->select(
                'ao.status',
                DB::raw("
                    CASE
                        WHEN ao.status = 1 THEN 'Exportbereit'
                        WHEN ao.status = 2 THEN 'Exportiert'
                        WHEN ao.status = 3 THEN 'Prüffall'
                    END AS status_name
                ")
            )
            //->whereNotIn('ao.status', array(3, 4))
            ->orderBy('status', 'asc')
            ->distinct();

        if(!is_null($selectedFilterLanguage)) {
            $statuses = $statuses->where('t_language_id', '=', $selectedFilterLanguage);
        }

        $statuses = $statuses->get();



        $mediumCategories = MediumCategory::all();

        return view('auction-objects.history-overview', ['selectedFilterStatus'=>$selectedFilterStatus, 'selectedFilterLanguage'=>$selectedFilterLanguage, 'pageLength'=>$pageLength, 'sortc'=>$sortc, 'sortd'=>$sortd, 'mediumCategories'=>$mediumCategories, 'languages'=>$languages, 'statuses'=>$statuses ]);
    }

    /**
     * @param $request
     */
    public function handleRequest($request) {

        // set status in session
        if (!is_null($request->status)) {
            session(['auctionObjectsHistoryStatus' => $request->status]);
        } else {
            session(['auctionObjectsHistoryStatus' => null]);
        }

        // set language in session
        if (!is_null($request->lang)) {
            session(['auctionObjectsHistoryLanguage' => $request->lang]);
        } else {
            session(['auctionObjectsHistoryLanguage' => null]);
        }

        // set page in session
        if (!is_null($request->page)) {
            session(['auctionObjectsHistoryPage' => $request->page]);
        } else {
            session(['auctionObjectsHistoryPage' => null]);
        }

        // set page length in session
        if ($request->len > 0) {
            session(['auctionObjectsHistoryLen' => $request->len]);
        } else {
            session(['auctionObjectsHistoryLen' => Auth::user()->table_page_length]);
        }

        // set sort column in session
        if (!is_null($request->sortc)) {
            session(['auctionObjectsHistorySortColumn' => $request->sortc]);
        } else {
            session(['auctionObjectsHistorySortColumn' => null]);
        }

        // set sort direction in session
        if (!is_null($request->sortd)) {
            session(['auctionObjectsHistorySortDirection' => $request->sortd]);
        } else {
            session(['auctionObjectsHistorySortDirection' => null]);
        }
    }

}
