<?php

namespace App\Http\Controllers\AuctionObjects;

use App\Artist;
use App\AuctionObject;
use App\Language;
use App\MediumCategory;
use App\SourceType;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class AuctionObjectsOverviewController extends Controller
{

    /**
     * AuctionObjectsOverviewController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->filtered == 1) {

            $this->handleRequest($request);
        } else {

            if (is_null(session('auctionObjectsLen'))) {
                // set table length
                session(['auctionObjectsLen' => Auth::user()->table_page_length]);
            }
        }

        $alert = '';

        if (!is_null($request->del) && $request->del == 0) {
            $alert = 'errorDelete';
        } elseif ($request->del == 1) {
            $alert = 'successDelete';
        } elseif ($request->c == 1) {
            $alert = 'successCreate';
        } elseif ($request->u == 1) {
            $alert = 'successUpdate';
        }

        $selectedFilterStatus = session('auctionObjectsStatus');
        $selectedFilterLanguage = session('auctionObjectsLanguage');
        $selectedFilterSourceType = session('auctionObjectsSourceType');
        $selectedFilterSearchColumn = session('auctionObjectsSearchColumn');
        $selectedFilterSearch = session('auctionObjectsSearch');
        $page = session('auctionObjectsPage');
        $pageLength = session('auctionObjectsLen');
        $sortc = session('auctionObjectsSortColumn');
        $sortd = session('auctionObjectsSortDirection');

        /*$sourceTypes = SourceType::orderBy('name', 'asc')
            ->get();*/


        /*$languages = Language::orderBy('lang_code', 'asc')
            ->get();*/

        // Language Filter - get entired languages
        $languages = DB::table('t_auction_object as ao')
            ->leftJoin('t_language as l', 'l.id', '=', 'ao.t_language_id')
            ->select(
                'ao.t_language_id as id',
                'l.language as language_name',
                'l.lang_code as lang_code'
            )
            ->distinct();

        $languages = $languages->get();

        // Status Filter - get entired statuses
        $statuses = DB::table('t_auction_object as ao')
            ->select(
                'ao.status',
                DB::raw("
                    CASE
                        WHEN ao.status = 1 THEN 'Exportbereit'
                        WHEN ao.status = 2 THEN 'Exportiert'
                        WHEN ao.status = 3 THEN 'Prüffall'
                    END AS status_name
                ")
            )
            //->whereNotIn('ao.status', array(3, 4))
            ->orderBy('status', 'asc')
            ->distinct();

        if(!is_null($selectedFilterLanguage)) {
            $statuses = $statuses->where('t_language_id', '=', $selectedFilterLanguage);
        }

        $statuses = $statuses->get();

        // Source Types Filter
        $sourceTypes = DB::table('t_auction_object as ao')
            ->leftJoin('t_source_type as s', 's.id', '=', 'ao.t_source_type_id')
            ->select(
                'ao.t_source_type_id as id',
                's.name as name'
            )
            ->distinct();

        if(!is_null($selectedFilterLanguage)) {
            $sourceTypes = $sourceTypes->where('t_language_id', '=', $selectedFilterLanguage);
        }

        if(!is_null($selectedFilterStatus)) {
            $sourceTypes = $sourceTypes->where('status', '=', $selectedFilterStatus);
        }

        $sourceTypes = $sourceTypes->get();

        // get all medium categories
        $mediumCategories = MediumCategory::all();

        // get all column names from auction object table
        $searchColumns = Schema::getColumnListing('t_auction_object');

        return view('auction-objects.overview', ['selectedFilterStatus'=>$selectedFilterStatus, 'selectedFilterLanguage'=>$selectedFilterLanguage, 'selectedFilterSourceType'=>$selectedFilterSourceType, 'page'=>$page, 'pageLength'=>$pageLength, 'sortc'=>$sortc, 'sortd'=>$sortd, 'mediumCategories'=>$mediumCategories, 'languages'=>$languages, 'statuses'=>$statuses, 'sourceTypes'=>$sourceTypes, 'searchColumns'=>$searchColumns, 'selectedFilterSearchColumn'=>$selectedFilterSearchColumn, 'selectedFilterSearch'=>$selectedFilterSearch, 'alert'=>$alert]);
    }

    /**
     * @param $request
     */
    public function handleRequest($request) {

        // set status in session
        if (!is_null($request->status)) {
            session(['auctionObjectsStatus' => $request->status]);
        } else {
            session(['auctionObjectsStatus' => null]);
        }

        // set language in session
        if (!is_null($request->lang)) {
            session(['auctionObjectsLanguage' => $request->lang]);
        } else {
            session(['auctionObjectsLanguage' => null]);
        }

        // set auction name in session
        if (!is_null($request->st)) {
            session(['auctionObjectsSourceType' => $request->st]);
        } else {
            session(['auctionObjectsSourceType' => null]);
        }

        // set page in session
        if (!is_null($request->page)) {
            session(['auctionObjectsPage' => $request->page]);
        } else {
            session(['auctionObjectsPage' => null]);
        }

        // set page length in session
        if ($request->len > 0) {
            session(['auctionObjectsLen' => $request->len]);
        } else {
            session(['auctionObjectsLen' => Auth::user()->table_page_length]);
        }

        // set sort column in session
        if (!is_null($request->sortc)) {
            session(['auctionObjectsSortColumn' => $request->sortc]);
        } else {
            session(['auctionObjectsSortColumn' => null]);
        }

        // set sort direction in session
        if (!is_null($request->sortd)) {
            session(['auctionObjectsSortDirection' => $request->sortd]);
        } else {
            session(['auctionObjectsSortDirection' => null]);
        }

        // set search column in session
        if (!is_null($request->sc)) {
            session(['auctionObjectsSearchColumn' => $request->sc]);
        } else {
            session(['auctionObjectsSearchColumn' => null]);
        }

        // set search column in session
        if (!is_null($request->s)) {
            session(['auctionObjectsSearch' => addslashes($request->s) ]);
        } else {
            session(['auctionObjectsSearch' => null]);
        }
    }
}
