<?php

namespace App\Http\Controllers\AuctionObjectsImport;

use App\Artist;
use App\AuctionObject;
use App\MediumCategory;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class AuctionObjectsImportOverviewController extends Controller
{

    /**
     * AuctionObjectsImportOverviewController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        if ($request->filtered == 1) {

            $this->handleRequest($request);
        } else {

            if (is_null(session('auctionObjectsUploadLen'))) {
                // set table length
                session(['auctionObjectsUploadLen' => Auth::user()->table_page_length]);
            }
        }

        $alert = '';

        if (!is_null($request->del) && $request->del == 0) {
            $alert = 'errorDelete';
        } elseif ($request->del == 1) {
            $alert = 'successDelete';
        } elseif ($request->c == 1) {
            $alert = 'successCreate';
        } elseif ($request->u == 1) {
            $alert = 'successUpdate';
        } elseif ($request->ps == 1) {
            $alert = 'processStarted';
        }

        $selectedFilterStatus = session('auctionObjectsUploadStatus');
        $selectedFilterLanguage = null; //session('auctionObjectsUploadLanguage');
        $selectedFilterAuctionName = null; //session('auctionObjectsUploadAuctionName');
        $page = session('auctionObjectsUploadPage');
        $pageLength = session('auctionObjectsUploadLen');
        $sortc = session('auctionObjectsUploadSortColumn');
        $sortd = session('auctionObjectsUploadSortDirection');

        $processStarted = $request->ps;

        $mediumCategories = MediumCategory::all();

        $auctionNames = DB::connection('mysql_stage')
            ->table('t_auction_object as ao')
            ->distinct()
            ->orderBy('auction_name', 'asc')
            ->get(['auction_name', 'source_type']);

        return view('auction-objects-import.import-overview', ['selectedFilterStatus'=>$selectedFilterStatus, 'selectedFilterLanguage'=>$selectedFilterLanguage, 'selectedFilterAuctionName'=>$selectedFilterAuctionName, 'page'=>$page, 'pageLength'=>$pageLength, 'sortc'=>$sortc, 'sortd'=>$sortd, 'processStarted'=>$processStarted, 'mediumCategories'=>$mediumCategories, 'auctionNames'=>$auctionNames, 'alert'=>$alert]);
    }

    /**
     * @param $request
     */
    public function handleRequest($request) {

        // set status in session
        if (!is_null($request->status)) {
            session(['auctionObjectsUploadStatus' => $request->status]);
        } else {
            session(['auctionObjectsUploadStatus' => null]);
        }

        // set language in session
        if (!is_null($request->lang)) {
            session(['auctionObjectsUploadLanguage' => $request->lang]);
        } else {
            session(['auctionObjectsUploadLanguage' => null]);
        }

        // set auction name in session
        if (!is_null($request->an)) {
            session(['auctionObjectsUploadAuctionName' => $request->an]);
        } else {
            session(['auctionObjectsUploadAuctionName' => null]);
        }

        // set page in session
        if (!is_null($request->page)) {
            session(['auctionObjectsUploadPage' => $request->page]);
        } else {
            session(['auctionObjectsUploadPage' => null]);
        }

        // set page length in session
        if ($request->len > 0) {
            session(['auctionObjectsUploadLen' => $request->len]);
        } else {
            session(['auctionObjectsUploadLen' => Auth::user()->table_page_length]);
        }

        // set sort column in session
        if (!is_null($request->sortc)) {
            session(['auctionObjectsUploadSortColumn' => $request->sortc]);
        } else {
            session(['auctionObjectsUploadSortColumn' => null]);
        }

        // set sort direction in session
        if (!is_null($request->sortd)) {
            session(['auctionObjectsUploadSortDirection' => $request->sortd]);
        } else {
            session(['auctionObjectsUploadSortDirection' => null]);
        }

    }

}
