<?php

namespace App\Http\Controllers\AuctionObjectsImport;

use App\AuctionObjectStageImport;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Maatwebsite\Excel\Facades\Excel;
use stdClass;

class StageImportFileController extends Controller
{

    /**
     * @param Request $request
     * @return string|null
     */
    public function upload(Request $request) {

        // handle upload
        $file = $request->file('import_file');

        $fileName = $file->getClientOriginalName();
        $fileExtension = $file->getClientOriginalExtension();
        $fileSize = $file->getSize();

        $uploadTime = Carbon::now()->format('Y-m-d\TH:i:s');

        $filePath = storage_path('app/public/imports/').$file->getClientOriginalName();
        $saveFile = $file->move(storage_path('app/public/imports'),$file->getClientOriginalName());

        // import file and create json object
        $jsonData = $this->readExcelFile($filePath, $fileName, $uploadTime);

        // call entired rest service
        $status = $this->callRestService($jsonData);

        if ($status == true) {
            return redirect()->route('auction-objects-import', ['fi' => 1]);
        }
    }

    /**
     * @param $filePath
     * @param $fileName
     * @param $uploadTime
     * @return false|string
     */
    private function readExcelFile($filePath, $fileName, $uploadTime) {

        $arrSheet = Excel::toArray(new AuctionObjectStageImport, $filePath);

        $arrDto = array();

        // get auction house
        $auctionHouse = $arrSheet[0][0][0];
        // get auction name
        $auctionName = $arrSheet[0][1][0];
        // get auction date
        $auctionDate = $arrSheet[0][2][0];

        // iterate the imported sheet array
        for($i=0; $i<count($arrSheet[0]); $i++) {

            // get the content rows
            if ($i>3) {

                // Create generic import object
                $objStageImport = new stdClass;

                // basic infos
                $objStageImport->filename = $fileName;
                $objStageImport->user = Auth::user()->id;
                $objStageImport->uploadTime = $uploadTime;
                $objStageImport->auctionHouse = $auctionHouse;
                $objStageImport->auctionName = $auctionName;
                $objStageImport->auctionDate = $auctionDate;

                // content
                $objStageImport->lotnum = $arrSheet[0][$i][0];
                $objStageImport->artist = $arrSheet[0][$i][1];
                $objStageImport->title = $arrSheet[0][$i][2];
                $objStageImport->indicators = $arrSheet[0][$i][3];
                $objStageImport->workDate = $arrSheet[0][$i][4];
                $objStageImport->medium = $arrSheet[0][$i][5];
                $objStageImport->dimensions = $arrSheet[0][$i][6];
                $objStageImport->estimates = $arrSheet[0][$i][7];
                $objStageImport->publisher = $arrSheet[0][$i][8];
                $objStageImport->printer = $arrSheet[0][$i][9];
                $objStageImport->catRaisAuthor = $arrSheet[0][$i][10];
                $objStageImport->catRaisNumber = $arrSheet[0][$i][11];
                $objStageImport->edition = $arrSheet[0][$i][12];
                $objStageImport->printingDate = $arrSheet[0][$i][13];
                $objStageImport->imageUrl = $arrSheet[0][$i][14];
                $objStageImport->lotUrl = $arrSheet[0][$i][15];

                // push object to dto array
                array_push($arrDto, $objStageImport);
            }

        }

        $jsonData = json_encode($arrDto);

        return $jsonData;
    }

    /**
     * @param $jsonData
     */
    private function callRestService($jsonData) {

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_IMPORTSTAGEFILE',null),
            CURLOPT_USERPWD => "admin:admin",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30000,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => $jsonData,
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);

        curl_close($curl);

        if ($err) {
            echo "cURL Error #:" . $err;

            return false;
        } else {

            return true;
        }
    }

}
