<?php

namespace App\Http\Controllers\AuctionObjectsStage;

use App\Artist;
use App\AuctionObject;
use App\Language;
use App\LanguageStage;
use App\MediumCategory;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class AuctionObjectsStageOverviewController extends Controller
{

    /**
     * AuctionObjectsOverviewController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('maintenanceMode');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        if ($request->filtered == 1) {

            $this->handleRequest($request);
        } else {

            if (is_null(session('auctionObjectsStageLen'))) {
                // set table length
                session(['auctionObjectsStageLen' => Auth::user()->table_page_length]);
            }
        }

        $alert = '';

        if (!is_null($request->del) && $request->del == 0) {
            $alert = 'errorDelete';
        } elseif ($request->del == 1) {
            $alert = 'successDelete';
        } elseif ($request->c == 1) {
            $alert = 'successCreate';
        } elseif ($request->u == 1) {
            $alert = 'successUpdate';
        } elseif ($request->ps == 1) {
            $alert = 'processStarted';
        } elseif ($request->ps == 2) {
            $alert = 'processAlreadyStarted';
        }

        $selectedFilterStatus = session('auctionObjectsStageStatus');
        $selectedFilterLanguage = session('auctionObjectsStageLanguage');
        $selectedFilterAuctionName = session('auctionObjectsStageAuctionName');
        $selectedFilterSearchColumn = session('auctionObjectsStageSearchColumn');
        $selectedFilterSearch = session('auctionObjectsStageSearch');
        $page = session('auctionObjectsStagePage');
        $pageLength = session('auctionObjectsStageLen');
        $sortc = session('auctionObjectsStageSortColumn');
        $sortd = session('auctionObjectsStageSortDirection');

        $processStarted = $request->ps;

        /*$languages = LanguageStage::orderBy('lang_code', 'asc')
            ->get();*/

        //$mediumCategories = MediumCategory::all();

        // language filter - get entired languages
        $languages = DB::connection('mysql_stage')
            ->table('t_auction_object as ao')
            ->leftJoin('t_language as l', 'l.id', '=', 'ao.t_language_id')
            ->select(
                'ao.t_language_id as id',
                'l.language as language_name',
                'l.lang_code as lang_code'
            )
            ->distinct();

        $languages = $languages->get();

        // status Filter - get entired statuses
        $statuses = DB::connection('mysql_stage')
            ->table('t_auction_object as ao')
            ->select(
                'ao.status',
                DB::raw("
                    CASE
                        WHEN ao.status = 0 THEN 'Neu'
                        WHEN ao.status = 1 THEN 'Übernehmen'
                        WHEN ao.status = 2 THEN 'Verwerfen'
                        WHEN ao.status = 5 THEN 'in Bearbeitung'
                        WHEN ao.status = 6 THEN 'Fehlerhaft'
                    END AS status_name
                ")
            )
            ->whereNotIn('ao.status', array(3, 4))
            ->orderBy('status', 'asc')
            ->distinct();

        if(!is_null($selectedFilterLanguage)) {
            $statuses = $statuses->where('t_language_id', '=', $selectedFilterLanguage);
        }

        $statuses = $statuses->get();

        // auction names filter
        $auctionNames = DB::connection('mysql_stage')
            ->table('t_auction_object as ao')
            ->select(
                'auction_no', 'source_type', 'auction_name', 'auction_date'
            )
            ->groupBy(['auction_no', 'source_type'])
            //->orderBy('auction_name', 'asc');
            ->orderBy('source_type', 'asc')
            ->orderBy('auction_name', 'asc')
            ->orderBy('auction_date', 'desc');

        if(!is_null($selectedFilterLanguage)) {
            $auctionNames = $auctionNames->where('t_language_id', '=', $selectedFilterLanguage);
        }

        if(!is_null($selectedFilterStatus)) {
            $auctionNames = $auctionNames->where('status', '=', $selectedFilterStatus);
        }

        $auctionNames = $auctionNames->get();

        return view('auction-objects-stage.stage-overview', ['selectedFilterStatus'=>$selectedFilterStatus, 'selectedFilterLanguage'=>$selectedFilterLanguage, 'selectedFilterAuctionName'=>$selectedFilterAuctionName, 'page'=>$page, 'pageLength'=>$pageLength, 'sortc'=>$sortc, 'sortd'=>$sortd, 'processStarted'=>$processStarted, 'languages'=>$languages, 'statuses'=>$statuses, 'auctionNames'=>$auctionNames, 'selectedFilterSearchColumn'=>$selectedFilterSearchColumn, 'selectedFilterSearch'=>$selectedFilterSearch, 'alert'=>$alert]);
    }

    /**
     * @param $request
     */
    public function handleRequest($request) {

        // set status in session
        if (!is_null($request->status)) {
            session(['auctionObjectsStageStatus' => $request->status]);
        } else {
            session(['auctionObjectsStageStatus' => null]);
        }

        // set language in session
        if (!is_null($request->lang)) {
            session(['auctionObjectsStageLanguage' => $request->lang]);
        } else {
            session(['auctionObjectsStageLanguage' => null]);
        }

        // set auction name in session
        if (!is_null($request->an)) {
            session(['auctionObjectsStageAuctionName' => $request->an]);
        } else {
            session(['auctionObjectsStageAuctionName' => null]);
        }

        // set page in session
        if (!is_null($request->page)) {
            session(['auctionObjectsStagePage' => $request->page]);
        } else {
            session(['auctionObjectsStagePage' => null]);
        }

        // set page length in session
        if ($request->len > 0) {
            session(['auctionObjectsStageLen' => $request->len]);
        } else {
            session(['auctionObjectsStageLen' => Auth::user()->table_page_length]);
        }

        // set sort column in session
        if (!is_null($request->sortc)) {
            session(['auctionObjectsStageSortColumn' => $request->sortc]);
        } else {
            session(['auctionObjectsStageSortColumn' => null]);
        }

        // set sort direction in session
        if (!is_null($request->sortd)) {
            session(['auctionObjectsStageSortDirection' => $request->sortd]);
        } else {
            session(['auctionObjectsStageSortDirection' => null]);
        }

        // set search column in session
        if (!is_null($request->sc)) {
            session(['auctionObjectsStageSearchColumn' => $request->sc]);
        } else {
            session(['auctionObjectsStageSearchColumn' => null]);
        }

        // set search column in session
        if (!is_null($request->s)) {
            session(['auctionObjectsStageSearch' => addslashes($request->s) ]);
        } else {
            session(['auctionObjectsStageSearch' => null]);
        }
    }

    /**
     *
     */
    public function startTransferProcess(Request $request) {

        $editor = $request->editor;

        $data = array(
            "t_editor_id" => $editor
        );

        $jsonData = json_encode($data);

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_STARTSTAGINGPROCESS').'?editor='.$editor,
            CURLOPT_USERPWD => env('SERVICE_USERPASSWORD'),
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30000,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => $jsonData,
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);
        $info = curl_getinfo($curl);
        $httpStatusCode = $info['http_code'];

        curl_close($curl);

        //$response = json_decode($response);

        if ($err) {
            echo "cURL Error #:" . $err;
        } else {

            if ($httpStatusCode == 406) {
                $migrationStatus = 2;
            } else {
                $migrationStatus = 1;
            }

            return redirect()->route('auction-objects-stage', ['ps' => $migrationStatus]);
        }

    }

}
