<?php

namespace App\Http\Controllers\GenderLookup;

use App\Artist;
use App\GenderLookup;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Validator;

class GenderLookupController extends Controller
{

    /**
     * GenderLookupController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('gender-lookup.create-gender-lookup', []);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // validate form
        $validator = Validator::make($request->all(), [
            'firstname'             => 'required',
            'country'               => 'required',
            'gender'                => 'required',
            'confidence'            => '',
            'firstname_normalized'  => '',
        ], [
            'firstname.required' => 'Bitte geben Sie den Vornamen ein',
            'country.required' => 'Bitte geben Sie das Land ein',
            'gender.required' => 'Bitte wählen Sie das Geschlecht',
            'confidence.required' => 'Bitte geben Sie das Vertrauens-Level ein ein',
            'firstname_normalized.required' => 'Bitte geben Sie den normalisierten Vornamen ein',
        ]);

        if ($request->country == '' || is_null($request->country)) {
            $country = '--';
        } else {
            $country = $request->country;
        }

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $genderLookup = new GenderLookup();
            $genderLookup->firstname = $request->firstname;
            $genderLookup->country = $country;
            $genderLookup->gender = $request->gender;
            $genderLookup->save();

            $this->restCallMatchAllGender($request);

            return redirect()->route('gender-lookup', ['c'=>1]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Request $request)
    {
        $genderLookupId = (int) $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $genderLookup = GenderLookup::where('id', $genderLookupId)
            ->first();

        return view('gender-lookup.edit-gender-lookup', ['genderLookup'=>$genderLookup, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $genderLookupId = (int) $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $validator = Validator::make($request->all(), [
            'firstname'             => 'required',
            'country'               => 'required',
            'gender'                => 'required',
            'confidence'            => '',
            'firstname_normalized'  => '',
        ], [
            'firstname.required' => 'Bitte geben Sie den Vornamen ein',
            'country.required' => 'Bitte geben Sie das Land ein',
            'gender.required' => 'Bitte wählen Sie das Geschlecht',
            'confidence.required' => 'Bitte geben Sie das Vertrauens-Level ein ein',
            'firstname_normalized.required' => 'Bitte geben Sie den normalisierten Vornamen ein',
        ]);

        if ($request->country == '' || is_null($request->country)) {
            $country = '--';
        } else {
            $country = $request->country;
        }

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $genderLookup = new GenderLookup();
            $genderLookup = $genderLookup->find($genderLookupId);

            $genderLookup->firstname = $request->firstname;
            $genderLookup->country = $country;
            $genderLookup->gender = $request->gender;

            $genderLookup->save();

            return redirect()->route('gender-lookup', ['page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd, 'u'=>1]);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $genderLookupId = (int) $request->id;
        $genderLookupPage = (int) $request->page;
        $genderLookupLength = (int) $request->length;
        $genderLookupSortColumn = (int) $request->sortc;
        $genderLookupSortDirection = $request->sortd;

        $genderLookup = GenderLookup::find($genderLookupId);

        if($genderLookup){
            $destroy = GenderLookup::destroy($genderLookupId);
            return redirect()->route('gender-lookup', ['del'=>1, 'page'=>$genderLookupPage, 'len'=>$genderLookupLength, 'sortc'=>$genderLookupSortColumn, 'sortd'=>$genderLookupSortDirection]);
        } else {
            return redirect()->route('gender-lookup', ['del'=>0, 'page'=>$genderLookupPage, 'len'=>$genderLookupLength, 'sortc'=>$genderLookupSortColumn, 'sortd'=>$genderLookupSortDirection]);
        }
    }

    private function restCallMatchAllGender(Request $request) {

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_MATCHALLGENDER',null),
            CURLOPT_USERPWD => env('SERVICE_USERPASSWORD'),
            CURLOPT_ENCODING => "",
            //CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 10000,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "",//$jsonData,
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);
        $info = curl_getinfo($curl);
        $httpStatusCode = $info['http_code'];

        curl_close($curl);

        //$response = json_decode($response);

        if ($err) {
            echo "cURL Error #:" . $err;
        } else {
            //dd(json_decode($response));

            return true;
        }

    }
}
