<?php

namespace App\Http\Controllers\Medium;

use App\Medium;
use App\MediumCategory;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Validator;

class MediumCategoryController extends Controller
{

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

        return view('medium.create-medium-category', []);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // do validation
        $validator = Validator::make($request->all(), [
            'name'             => 'required',
        ], [
            'name'             => 'Bitte geben Sie den Namen ein',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $medium = new MediumCategory();

            $medium->name = $request->category;
            $medium->save();

            return redirect()->route('medium-categories', ['c'=>1]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Request $request)
    {
        $mediumCategoryId = (int) $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $mediumCategory = MediumCategory::where('id', $mediumCategoryId)
            ->first();

        return view('medium.edit-medium-category', ['mediumCategory'=>$mediumCategory, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $mediumCategoryId = (int) $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $validator = Validator::make($request->all(), [
            'name'                  => 'required',
        ], [
            'name'                  => 'Bitte geben Sie den Namen ein',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $mediumCategory = new MediumCategory();
            $mediumCategory = $mediumCategory->find($mediumCategoryId);

            $mediumCategory->name = $request->name;
            $mediumCategory->save();

            return redirect()->route('medium-categories', ['u'=>1, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $mediumCategoryId = (int) $request->medium_category_id;
        $mediumCategoryPage = (int) $request->medium_category_page;
        $mediumCategoryLength = (int) $request->medium_category_length;
        $mediumCategorySortColumn = (int) $request->medium_category_sort_column;
        $mediumCategorySortDirection = $request->medium_category_sort_direction;

        $mediumCategory = MediumCategory::find($mediumCategoryId);

        if($mediumCategory){
            $destroy = MediumCategory::destroy($mediumCategoryId);
            return redirect()->route('medium-categories', ['del'=>1, 'page'=>$mediumCategoryPage, 'len'=>$mediumCategoryLength, 'sortc'=>$mediumCategorySortColumn, 'sortd'=>$mediumCategorySortDirection]);
        } else {
            return redirect()->route('medium-categories', ['del'=>0, 'page'=>$mediumCategoryPage, 'len'=>$mediumCategoryLength, 'sortc'=>$mediumCategorySortColumn, 'sortd'=>$mediumCategorySortDirection]);
        }
    }
}
