<?php

namespace App\Http\Controllers\Medium;

use App\Artist;
use App\Medium;
use App\MediumAbstract;
use App\MediumCategory;
use App\MediumKeyword;
use App\MediumKeywordMediumAbstract;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Validator;

class MediumController extends Controller
{

    /**
     * Display a listing of the resource.
     *
     * @param Request $request
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index(Request $request)
    {
        $mediums = Medium::all();

        $alert = '';

        if (!is_null($request->del) && $request->del == 0) {
            $alert = 'errorDelete';
        } elseif ($request->del == 1) {
            $alert = 'successDelete';
        } elseif ($request->c == 1) {
            $alert = 'successCreate';
        } elseif ($request->u == 1) {
            $alert = 'successUpdate';
        }

        return view('medium.mediums-overview', ['mediums'=>$mediums, 'alert'=>$alert]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

        $mediumCategories = MediumCategory::all();

        return view('medium.create-medium', ['mediumCategories'=>$mediumCategories]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // do validation
        $validator = Validator::make($request->all(), [
            'searchword_de'             => 'required_without_all:searchword_en,searchword_fr',
            'searchword_en'             => 'required_without_all:searchword_de,searchword_fr',
            'searchword_fr'             => 'required_without_all:searchword_de,searchword_en',
            't_medium_category_id'      => 'required',
        ], [
            'searchword_de'             => 'Bitte geben Sie das deutsche Suchwort ein',
            'searchword_en'             => 'Bitte geben Sie das englische Suchwort ein',
            'searchword_fr'             => 'Bitte geben Sie das französische Suchwort ein',
            't_medium_category_id'      => 'Bitte weise Sie die Grobtechnik zu',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $medium = new Medium();

            $medium->searchword_de = $request->searchword_de;
            $medium->searchword_en = $request->searchword_en;
            $medium->searchword_fr = $request->searchword_fr;
            $medium->t_medium_category_id = $request->t_medium_category_id;
            $medium->save();

            $this->restCallMatchAllMediums($request);

            return redirect()->route('mediums', ['c'=>1]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Request $request)
    {
        $mediumId = (int) $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $medium = Medium::where('id', $mediumId)
            ->first();

        $mediumCategories = MediumCategory::all();

        return view('medium.edit-medium', ['medium'=>$medium, 'mediumCategories'=>$mediumCategories, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $mediumId = (int) $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $validator = Validator::make($request->all(), [
            'searchword_de'             => 'required_without_all:searchword_en,searchword_fr',
            'searchword_en'             => 'required_without_all:searchword_de,searchword_fr',
            'searchword_fr'             => 'required_without_all:searchword_de,searchword_en',
            't_medium_category_id'      => 'required',
        ], [
            'searchword_de'             => 'Bitte geben Sie das deutsche Suchwort ein',
            'searchword_en'             => 'Bitte geben Sie das englische Suchwort ein',
            'searchword_fr'             => 'Bitte geben Sie das französische Suchwort ein',
            't_medium_category_id'      => 'Bitte weise Sie die Grobtechnik zu',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $medium = new Medium();
            $medium = $medium->find($mediumId);

            $medium->searchword_de = $request->searchword_de;
            $medium->searchword_en = $request->searchword_en;
            $medium->searchword_fr = $request->searchword_fr;
            $medium->t_medium_category_id = $request->t_medium_category_id;
            $medium->save();

            $this->restCallMatchAllMediums($request);

            return redirect()->route('mediums', ['u'=>1, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $mediumId = (int) $request->medium_id;
        $mediumPage = (int) $request->medium_page;
        $mediumLength = (int) $request->medium_length;
        $mediumSortColumn = (int) $request->medium_sort_column;
        $mediumSortDirection = $request->medium_sort_direction;

        $medium = Medium::find($mediumId);

        if($medium){
            $destroy = Medium::destroy($mediumId);
            return redirect()->route('mediums', ['del'=>1, 'page'=>$mediumPage, 'len'=>$mediumLength, 'sortc'=>$mediumSortColumn, 'sortd'=>$mediumSortDirection]);
        } else {
            return redirect()->route('mediums', ['del'=>0, 'page'=>$mediumPage, 'len'=>$mediumLength, 'sortc'=>$mediumSortColumn, 'sortd'=>$mediumSortDirection]);
        }
    }

    /**
     *
     */
    public function restCallMatchAllMediums(Request $request) {

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => env('SERVICE_URL_MATCHALLMEDIUMS',null),
            CURLOPT_USERPWD => env('SERVICE_USERPASSWORD'),
            CURLOPT_ENCODING => "",
            //CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 10000,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "",//$jsonData,
            CURLOPT_HTTPHEADER => array(
                "accept: */*",
                "accept-language: en-US,en;q=0.8",
                "content-type: application/json",
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);
        $info = curl_getinfo($curl);
        $httpStatusCode = $info['http_code'];

        curl_close($curl);

        //$response = json_decode($response);

        if ($err) {
            echo "cURL Error #:" . $err;
        } else {
            //dd(json_decode($response));
            return true;
        }

    }
}
