<?php

namespace App\Http\Controllers\SourceTypes;

use App\Medium;
use App\SourceType;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Validator;

class SourceTypeController extends Controller
{

    /**
     * SourceTypeController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * @param Request $request
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index(Request $request)
    {
        $sourceTypes = SourceType::all();

        $alert = '';

        if (!is_null($request->del) && $request->del == 0) {
            $alert = 'errorDelete';
        } elseif ($request->del == 1) {
            $alert = 'successDelete';
        } elseif ($request->c == 1) {
            $alert = 'successCreate';
        } elseif ($request->u == 1) {
            $alert = 'successUpdate';
        }

        return view('source-types.source-types-overview', ['sourceTypes'=>$sourceTypes, 'alert'=>$alert]);
    }

    /**
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function create()
    {
        return view('source-types.create-source-type', []);
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        // do validation
        $validator = Validator::make($request->all(), [
            'name'             => 'required',
            'location'         => '',
            'url'              => 'required',
            'Unter_ID'         => '',
        ], [
            'name'             => 'Bitte geben Sie den Namen ein',
            'location'         => 'Bitte geben Sie den Standort ein',
            'url'              => 'Bitte geben Sie die URL ein',
            'Unter_ID'         => 'Bitte wählen Sie die Unter ID',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $sourceType = new SourceType();

            $sourceType->name = $request->name;
            $sourceType->location = $request->location;
            $sourceType->url = $request->url;
            $sourceType->Unter_ID = $request->Unter_ID;
            $sourceType->save();

            return redirect()->route('source-types', ['c'=>1]);
        }
    }

    /**
     * @param Request $request
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function edit($id, Request $request)
    {
        $sourceTypeId = $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $sourceType = SourceType::where('id', $sourceTypeId)
            ->first();

        return view('source-types.edit-source-type', ['sourceType'=>$sourceType, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
    }

    public function update(Request $request, $id)
    {

        $sourceTypeId = (int) $id;

        $page = $request->page;
        $len = $request->len;
        $sortc = $request->sortc;
        $sortd = $request->sortd;

        $validator = Validator::make($request->all(), [
            'name'             => 'required',
            'location'         => '',
            'url'              => 'required',
            'Unter_ID'         => '',
        ], [
            'name'             => 'Bitte geben Sie den Namen ein',
            'location'         => 'Bitte geben Sie den Standort ein',
            'url'              => 'Bitte geben Sie die URL ein',
            'Unter_ID'         => 'Bitte wählen Sie die Unter ID',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $sourceType = new SourceType();
            $sourceType = $sourceType->find($sourceTypeId);

            $sourceType->name = $request->name;
            $sourceType->location = $request->location;
            $sourceType->url = $request->url;
            $sourceType->Unter_ID = $request->Unter_ID;
            $sourceType->save();

            return redirect()->route('source-types', ['u'=>1, 'page'=>$page, 'len'=>$len, 'sortc'=>$sortc, 'sortd'=>$sortd]);
        }
    }

    /**
     * Delete Source Type
     *
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy(Request $request)
    {
        $sourceTypeId = (int) $request->source_type_id;
        $sourceTypePage = (int) $request->source_type_page;
        $sourceTypeLength = (int) $request->source_type_length;
        $sourceTypeSortColumn = (int) $request->source_type_sort_column;
        $sourceTypeSortDirection = $request->source_type_sort_direction;

        $sourceType = SourceType::find($sourceTypeId);

        if($sourceType){
            $destroy = SourceType::destroy($sourceTypeId);
            return redirect()->route('source-types', ['del'=>1, 'page'=>$sourceTypePage, 'len'=>$sourceTypeLength, 'sortc'=>$sourceTypeSortColumn, 'sortd'=>$sourceTypeSortDirection]);
        } else {
            return redirect()->route('source-types', ['del'=>0, 'page'=>$sourceTypePage, 'len'=>$sourceTypeLength, 'sortc'=>$sourceTypeSortColumn, 'sortd'=>$sourceTypeSortDirection]);
        }
    }
}
