<?php

namespace App\Http\Controllers\Users;

use App\User;
use App\UserRole;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Validator;

class UserController extends Controller
{

    /**
     * UserController constructor.
     */
    public function __construct()
    {
        $this->middleware('auth');

    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $userRoles = UserRole::get();

        $alert = '';

        return view('users.create-user', ['userRoles'=>$userRoles]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // validate form
        $validator = Validator::make($request->all(), [
            'user_role'             => 'required',
            'first_name'            => 'required',
            'last_name'             => 'required',
            'email'                 => 'required|unique:users|email',
            'password'              => 'required',
            'table_page_length'     => 'required',
        ], [
            'user_role.required' => 'Bitte Sie die Benutzerrolle',
            'first_name.required' => 'Bitte geben Sie Ihren Vornamen ein',
            'last_name.required' => 'Bitte geben Sie Ihre Nachnamen ein',
            'email.required' => 'Bitte geben Sie Ihre E-Mail Adresse ein',
            'email.email' => 'Bitte geben Sie eine korrekte E-Mail Adresse ein',
            'email.unique' => 'Zu dieser Adresse existiert bereits ein Account. Bitte verwenden Sie eine andere E-Mail Adresse.',
            'password.required' => 'Bitte geben Sie Ihr gewünschtes Passwort ein',
            'table_page_length.required' => 'Bitte geben Sie die Anzahl der anzuzeigenden Tabellenzeilen an',
        ]);

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $user = new User();
            $user->first_name = $request->first_name;
            $user->last_name = $request->last_name;
            $user->user_role_id = $request->user_role;
            $user->email = $request->email;
            $user->password = bcrypt($request->password);
            $user->table_page_length = $request->table_page_length;
            $user->is_active = 1;
            //$user->created_at = Carbon::now();
            $user->save();

            return redirect()->route('users', ['c'=>1]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, $id)
    {
        $userId = (int) $id;

        $user = User::where('id', $userId)
            ->first();

        $userRoles = UserRole::get();

        $alert = '';

        if (!is_null($request->u) && $request->u == 1) {
            $alert = 'successUpdate';
        }

        return view('users.edit-user', ['user'=>$user, 'userRoles'=>$userRoles, 'alert'=>$alert]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $userId = (int) $id;

        if ($request->password) {
            // validate form
            $validator = Validator::make($request->all(), [
                'user_role'             => 'required',
                'first_name'            => 'required',
                'last_name'             => 'required',
                'email'                 => 'required|email',
                'password'              => 'required',
                'table_page_length'     => 'required',
            ], [
                'user_role.required' => 'Bitte Sie die Benutzerrolle',
                'first_name.required' => 'Bitte geben Sie Ihren Vornamen ein',
                'last_name.required' => 'Bitte geben Sie Ihre Nachnamen ein',
                'email.required' => 'Bitte geben Sie Ihre E-Mail Adresse ein',
                'email.email' => 'Bitte geben Sie eine korrekte E-Mail Adresse ein',
                'email.unique' => 'Zu dieser Adresse existiert bereits ein Account. Bitte verwenden Sie eine andere E-Mail Adresse.',
                'password.required' => 'Bitte geben Sie Ihr gewünschtes Passwort ein',
            ]);
        } else {
            // validate form
            $validator = Validator::make($request->all(), [
                'user_role'             => 'required',
                'first_name'            => 'required',
                'last_name'             => 'required',
                'email'                 => 'required|email',
            ], [
                'user_role.required' => 'Bitte Sie die Benutzerrolle',
                'first_name.required' => 'Bitte geben Sie Ihren Vornamen ein',
                'last_name.required' => 'Bitte geben Sie Ihre Nachnamen ein',
                'email.required' => 'Bitte geben Sie Ihre E-Mail Adresse ein',
                'email.email' => 'Bitte geben Sie eine korrekte E-Mail Adresse ein',
                'email.unique' => 'Zu dieser Adresse existiert bereits ein Account. Bitte verwenden Sie eine andere E-Mail Adresse.',
                'table_page_length.required' => 'Bitte geben Sie die Anzahl der anzuzeigenden Tabellenzeilen an',
            ]);
        }

        // if validation fails
        if ($validator->fails()) {

            return redirect(URL::previous())
                ->withErrors($validator->errors(), 'formErrors')
                ->withInput($request->input());

        } else {

            // generate Object, fill it, write to DB
            $user = new User();
            $user = $user->find($userId);

            $user->first_name = $request->first_name;
            $user->last_name = $request->last_name;
            $user->user_role_id = $request->user_role;
            $user->email = $request->email;
            if ($request->password) {
                $user->password = bcrypt($request->password);
            }
            $user->table_page_length = $request->table_page_length;
            $user->is_active = 1;
            //$user->created_at = Carbon::now();
            $user->save();

            if (Auth::user()->user_role_id == 1) {

                return redirect()->route('users', ['u'=>1]);
            } else {

                return redirect()->route('edit-user', ['id'=>$userId, 'u'=>1]);
            }
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $userId = (int) $request->user_id;

        $user = User::find($userId);

        if($user){
            $destroy = User::destroy($userId);
            return redirect()->route('users', ['del'=>1]);
        } else {
            return redirect()->route('users', ['del'=>0]);
        }
    }
}
